BpmDetector class

A BPM detector based on spectral flux and autocorrelation.

Constructors

BpmDetector()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

detect(Float32List samples, int sampleRate) double
Detects the BPM of the given audio samples.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited