EnergyDetector class

A simple energy detector that calculates the root mean square (RMS) of the audio samples.

Implemented types

Constructors

EnergyDetector()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

detect(Float32List samples, int sampleRate) double
Detects the energy of the given audio samples as a value between 0.0 and 1.0.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited