FeatureDetector<T> class abstract

An abstract class for feature detectors that analyze audio samples and extract specific features.

Implementers

Constructors

FeatureDetector()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

detect(Float32List samples, int sampleRate) → T
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited