AnalysisResult class

Represents the result of analyzing a music file, including the original file data, the extracted music data, and a confidence score for the analysis.

Constructors

AnalysisResult({required FileData fileData, required MusicData musicData, required double confidence})

Properties

confidence double
final
fileData FileData
final
hashCode int
The hash code for this object.
no setterinherited
musicData MusicData
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited