data/camelot_key_predicition_set library

Classes

CamelotKeyPredictionSet
Represents a set of predictions for the key of a music track, including multiple predictions with their confidence scores and a method to retrieve the best prediction.