Complex class

A simple class to represent complex numbers and perform basic operations.

Constructors

Complex(double real, double imag)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
imag double
final
magnitude double
no setter
real double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator *(Complex other) Complex
operator +(Complex other) Complex
operator -(Complex other) Complex
operator ==(Object other) bool
The equality operator.
inherited