Extension enum

An enumeration representing supported audio file extensions and their corresponding decoders.

Inheritance
Available extensions

Values

mp3 → const Extension
wav → const Extension
invalid → const Extension

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getDecoder() Decoder
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromString(String extension) Extension

Constants

values → const List<Extension>
A constant List of the values in this enum, in order of their declaration.