FileData class

A class representing metadata about an audio file, including its name, extension, path, and size in bytes.

Constructors

FileData({required String fileName, required Extension extension, required String path, required int sizeInBytes, int sampleRate = 0, int channels = 0, Duration duration = const Duration()})

Properties

channels int
getter/setter pair
duration Duration
getter/setter pair
extension Extension
final
fileName String
final
hashCode int
The hash code for this object.
no setterinherited
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleRate int
getter/setter pair
sizeInBytes int
final
sizeInGB double
no setter
sizeInKB double
no setter
sizeInMB double
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited