KeyCandidate class
A class representing a candidate key with its tonic, mode (major/minor), and confidence score.
Constructors
- KeyCandidate({required int tonic, required bool isMajor, required double score})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited