MusicData class

Represents the extracted music data from an analysis, including BPM, key predictions, energy level, and sample rate.

Constructors

MusicData({required double bpm, required CamelotKeyPredictionSet key, required double energy, required int sampleRate})

Properties

bpm double
final
energy double
final
hashCode int
The hash code for this object.
no setterinherited
key CamelotKeyPredictionSet
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleRate int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited