Decoder class abstract

An abstract class for decoders that convert raw audio file bytes into audio data and sample rate information.

Implementers

Constructors

Decoder()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(Uint8List bytes) Future<({AudioData audioData, int sampleRate})>
getChannels(Uint8List bytes) int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited