Mp3Decoder class

A decoder for MP3 audio files. This class implements the Decoder interface and provides a method to decode MP3 data into audio samples and sample rate.

Implemented types

Constructors

Mp3Decoder()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(Uint8List bytes) Future<({AudioData audioData, int sampleRate})>
override
getChannels(Uint8List bytes) int
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited