WavDecoder class
A decoder for WAV audio files that extracts the audio samples and sample rate from the file data.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decode(
Uint8List bytes) → Future< ({AudioData audioData, int sampleRate})> -
override
-
getChannels(
Uint8List bytes) → int -
Gets the number of channels in the WAV file from the header bytes.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited