FrameSplitter class

A utility class for splitting audio samples into overlapping frames for analysis.

Constructors

FrameSplitter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

split(Float32List samples, int frameSize, int hopSize) List<Float32List>