CamelotKey enum
Represents a musical key in the Camelot notation system, which is commonly used by DJs to indicate the key of a track for harmonic mixing.
Values
- oneA → const CamelotKey
-
const CamelotKey(1, 'A') - oneB → const CamelotKey
-
const CamelotKey(1, 'B') - twoA → const CamelotKey
-
const CamelotKey(2, 'A') - twoB → const CamelotKey
-
const CamelotKey(2, 'B') - threeA → const CamelotKey
-
const CamelotKey(3, 'A') - threeB → const CamelotKey
-
const CamelotKey(3, 'B') - fourA → const CamelotKey
-
const CamelotKey(4, 'A') - fourB → const CamelotKey
-
const CamelotKey(4, 'B') - fiveA → const CamelotKey
-
const CamelotKey(5, 'A') - fiveB → const CamelotKey
-
const CamelotKey(5, 'B') - sixA → const CamelotKey
-
const CamelotKey(6, 'A') - sixB → const CamelotKey
-
const CamelotKey(6, 'B') - sevenA → const CamelotKey
-
const CamelotKey(7, 'A') - sevenB → const CamelotKey
-
const CamelotKey(7, 'B') - eightA → const CamelotKey
-
const CamelotKey(8, 'A') - eightB → const CamelotKey
-
const CamelotKey(8, 'B') - nineA → const CamelotKey
-
const CamelotKey(9, 'A') - nineB → const CamelotKey
-
const CamelotKey(9, 'B') - tenA → const CamelotKey
-
const CamelotKey(10, 'A') - tenB → const CamelotKey
-
const CamelotKey(10, 'B') - elevenA → const CamelotKey
-
const CamelotKey(11, 'A') - elevenB → const CamelotKey
-
const CamelotKey(11, 'B') - twelveA → const CamelotKey
-
const CamelotKey(12, 'A') - twelveB → const CamelotKey
-
const CamelotKey(12, 'B')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- mode → String
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - number → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromString(
String key) → CamelotKey?
Constants
-
values
→ const List<
CamelotKey> - A constant List of the values in this enum, in order of their declaration.