CamelotKeyPredictionSet class
Represents a set of predictions for the key of a music track, including multiple predictions with their confidence scores and a method to retrieve the best prediction.
Constructors
-
CamelotKeyPredictionSet({required List<
CamelotKeyPrediction> predictions})
Properties
- bestPrediction → CamelotKeyPrediction
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
predictions
↔ List<
CamelotKeyPrediction> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited