Complex class
A simple class to represent complex numbers and perform basic operations.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator *(
Complex other) → Complex -
operator +(
Complex other) → Complex -
operator -(
Complex other) → Complex -
operator ==(
Object other) → bool -
The equality operator.
inherited