FFT class
A class that implements the Fast Fourier Transform (FFT) algorithm to convert time-domain signals into their frequency-domain representation.
Constructors
- FFT()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
forward(
List< double> signal) → List<Complex> -
transform(
Float64List real, Float64List imaginary) → void