SpectralFlux class
A utility class for computing spectral flux, which is a measure of how much the spectrum of a signal changes over time.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
compute(
List< List< spectra) → List<double> >double> - Computes the spectral flux for a list of spectra, returning a list of flux values where the first value is 0 (since there is no previous spectrum to compare to).
-
positiveDifference(
List< double> current, List<double> previous) → double - Computes the positive difference between two spectra, summing only the positive changes in magnitude across all frequency bins.